@@ -99,7 +99,10 @@ struct cmd_node {
 struct cmd_node*
 commands_root(void)
 {
-	return commands_new(NULL, NULL, NULL, NULL, NULL, NULL);
+	struct cmd_node *new = calloc(1, sizeof(struct cmd_node));
+	if (new == NULL) fatalx("lldpctl", "out of memory");
+	TAILQ_INIT(&new->subentries);
+	return new;
 }
 
 /**
@@ -167,18 +170,15 @@ commands_new(struct cmd_node *root,
     void *arg)
 {
 	struct cmd_node *new = calloc(1, sizeof(struct cmd_node));
-	if (new == NULL) {
-		log_warn("lldpctl", "unable to allocate memory for new command node");
-		return NULL;
-	}
+	if (new == NULL)
+		fatalx("lldpctl", "out of memory");
 	new->token = token;
 	new->doc = doc;
 	new->validate = validate;
 	new->execute = execute;
 	new->arg = arg;
 	TAILQ_INIT(&new->subentries);
-	if (root != NULL)
-		TAILQ_INSERT_TAIL(&root->subentries, new, next);
+	TAILQ_INSERT_TAIL(&root->subentries, new, next);
 	return new;
 }
 
