@@ -717,14 +717,18 @@ display_interface(lldpctl_conn_t *conn, struct writer *w, int hidden,
 	tag_start(w, "interface", "Interface");
 	tag_attr(w, "name", "",
 	    lldpctl_atom_get_str(iface, lldpctl_k_interface_name));
-	tag_attr(w, "via" , "via",
-	    lldpctl_atom_get_str(port, lldpctl_k_port_protocol));
-	if (details > DISPLAY_BRIEF) {
-		if (!local)
+	if (!local) {
+		tag_attr(w, "via" , "via",
+		    lldpctl_atom_get_str(port, lldpctl_k_port_protocol));
+		if (details > DISPLAY_BRIEF) {
 			tag_attr(w, "rid" , "RID",
 			    lldpctl_atom_get_str(chassis, lldpctl_k_chassis_index));
-		tag_attr(w, "age" , "Time",
-		    display_age(lldpctl_atom_get_int(port, lldpctl_k_port_age)));
+			tag_attr(w, "age" , "Time",
+			    display_age(lldpctl_atom_get_int(port, lldpctl_k_port_age)));
+		}
+	} else {
+		tag_datatag(w, "status", "Administrative status",
+		    lldpctl_atom_get_str(port, lldpctl_k_port_status));
 	}
 
 	display_chassis(w, chassis, details);
@@ -818,7 +822,7 @@ display_local_interfaces(lldpctl_conn_t *conn, struct writer *w,
 	tag_start(w, "lldp", "LLDP interfaces");
 	while ((iface = cmd_iterate_on_interfaces(conn, env))) {
 		lldpctl_atom_t *port;
-		port      = lldpctl_get_port(iface);
+		port = lldpctl_get_port(iface);
 		display_interface(conn, w, hidden, iface, port, details, protocol);
 		lldpctl_atom_dec_ref(port);
 	}
