@@ -314,6 +314,10 @@ _lldpctl_do_something(lldpctl_conn_t *conn,
 {
 	ssize_t rc;
 
+	if (conn->state == CONN_STATE_WATCHING)
+		/* The connection cannot be used anymore. */
+		return SET_ERROR(conn, LLDPCTL_ERR_INVALID_STATE);
+
 	if (conn->state == CONN_STATE_IDLE) {
 		/* We need to build the message to send, then send
 		 * it. */
@@ -327,7 +331,7 @@ _lldpctl_do_something(lldpctl_conn_t *conn,
 			conn->state_data[0] = 0;
 	}
 	if (conn->state == state_send &&
-	    (state_data == NULL || !strncmp(conn->state_data, state_data, sizeof(conn->state_data)))) {
+	    (state_data == NULL || !strncmp(conn->state_data, state_data, sizeof(conn->state_data) - 1))) {
 		/* We need to send the currently built message */
 		rc = lldpctl_send(conn);
 		if (rc < 0)
@@ -335,7 +339,7 @@ _lldpctl_do_something(lldpctl_conn_t *conn,
 		conn->state = state_recv;
 	}
 	if (conn->state == state_recv &&
-	    (state_data == NULL || !strncmp(conn->state_data, state_data, sizeof(conn->state_data)))) {
+	    (state_data == NULL || !strncmp(conn->state_data, state_data, sizeof(conn->state_data) - 1))) {
 		/* We need to receive the answer */
 		while ((rc = ctl_msg_recv_unserialized(&conn->input_buffer,
 			    &conn->input_buffer_len,
@@ -371,6 +375,27 @@ lldpctl_watch_callback(lldpctl_conn_t *conn,
 	if (rc == 0) {
 		conn->watch_cb = cb;
 		conn->watch_data = data;
+		conn->state = CONN_STATE_WATCHING;
+	}
+	return rc;
+}
+
+int
+lldpctl_watch_callback2(lldpctl_conn_t *conn,
+    lldpctl_change_callback2 cb,
+    void *data)
+{
+	int rc;
+
+	RESET_ERROR(conn);
+
+	rc = _lldpctl_do_something(conn,
+	    CONN_STATE_SET_WATCH_SEND, CONN_STATE_SET_WATCH_RECV, NULL,
+	    SUBSCRIBE, NULL, NULL, NULL, NULL);
+	if (rc == 0) {
+		conn->watch_cb2 = cb;
+		conn->watch_data = data;
+		conn->state = CONN_STATE_WATCHING;
 	}
 	return rc;
 }
@@ -382,7 +407,7 @@ lldpctl_watch(lldpctl_conn_t *conn)
 
 	RESET_ERROR(conn);
 
-	if (conn->state != CONN_STATE_IDLE)
+	if (conn->state != CONN_STATE_WATCHING)
 		return SET_ERROR(conn, LLDPCTL_ERR_INVALID_STATE);
 
 	conn->watch_triggered = 0;
